==> havp_0.76.orig.tar.gz: havp-0.76/havp/proxyhandler.h <==
/***************************************************************************
                          proxyhandler.h  -  description
                             -------------------
    begin                : So Feb 20 2005
    copyright            : (C) 2005 by Christian Hilgers
    email                : christian@hilgers.ag
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef PROXYHANDLER_H
#define PROXYHANDLER_H

#include "connectiontobrowser.h"
#include "connectiontoserver.h"
#include "genericscanner.h"
#include "logfile.h"
#include "filehandler.h"
#include "default.h"
#include "params.h"

#include <iostream>
#include <string>
#include <deque>
#include <stdlib.h>
#include <errno.h>
#include <sys/types.h>
#include <signal.h>

using namespace std;


class ProxyHandler {

private:

bool newinstance;

bool HeaderSend;

bool BrowserDropped;

ConnectionToBrowser ToBrowser;
ConnectionToServer ToServer;

//PSEstart
//bool ProxyMessage( int CommunicationAnswerT );
bool ProxyMessage( int CommunicationAnswerT, GenericScanner *VirusScannerT );
//PSEend

int Communication( SocketHandler *ProxyServerT, GenericScanner *VirusScannerT );
 
public:

 bool Proxy ( SocketHandler *ProxyServerT, GenericScanner *VirusScannerT );
 
 
	ProxyHandler();
	~ProxyHandler();
};

#endif

==> havp_0.79.orig.tar.gz: havp-0.79/havp/proxyhandler.h <==
/***************************************************************************
                          proxyhandler.h  -  description
                             -------------------
    begin                : So Feb 20 2005
    copyright            : (C) 2005 by Christian Hilgers
    email                : christian@hilgers.ag
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef PROXYHANDLER_H
#define PROXYHANDLER_H

#include "default.h"
#include "connectiontobrowser.h"
#include "connectiontohttp.h"
#include "scannerhandler.h"

#include <string>

using namespace std;

class ProxyHandler {

private:

bool HeaderSend;
bool BrowserDropped;
bool DropBrowser;
bool ScannerUsed;
bool UnlockDone;
bool AnswerDone;
bool ReinitDone;
bool ServerClosed;
bool ServerConnected;
bool DropServer;
int alivecount;
string ConnectedHost;
int ConnectedPort;

string Header;

ConnectionToBrowser ToBrowser;
ConnectionToHTTP ToServer;

bool UseParentProxy;
string ParentHost;
int ParentPort;

bool ProxyMessage( int CommunicationAnswerT, string Answer );
int CommunicationHTTP( ScannerHandler *Scanners, bool ScannerOff );
int CommunicationFTP( ScannerHandler *Scanners, bool ScannerOff );

#ifdef SSLTUNNEL
int CommunicationSSL();
#endif

public:

void Proxy( SocketHandler *ProxyServerT, ScannerHandler *Scanners );
 
ProxyHandler();
~ProxyHandler();

};

#endif
